# LIB_CHECK_FFTW
#------------------
# Checks for the fftw library and header files.
AC_DEFUN([LIB_CHECK_FFTW],
[

    AC_MSG_CHECKING([for fftw])

    detmon_fftw_check_header="sfftw.h"
    detmon_fftw_check_lib="libsfftw.a"

    detmon_fftw_includes=""
    detmon_fftw_libraries=""

    AC_ARG_WITH(fftw,
                AC_HELP_STRING([--with-fftw],
                               [location where fftw is installed]),
                [
                    detmon_with_fftw_includes=$withval/include
                    detmon_with_fftw_libs=$withval/lib
                ])

    AC_ARG_WITH(fftw-includes,
                AC_HELP_STRING([--with-fftw-includes],
                               [location of the fftw header files]),
                detmon_with_fftw_includes=$withval)

    AC_ARG_WITH(fftw-libs,
                AC_HELP_STRING([--with-fftw-libs],
                               [location of the fftw library]),
                detmon_with_fftw_libs=$withval)

    AC_ARG_ENABLE(fftw,
                  AC_HELP_STRING([--enable-fftw],
                                 [disables checks for the fftw library and headers]),
                  detmon_enable_fftw_test=yes,
                  detmon_enable_fftw_test=no)


    if test "x$detmon_enable_fftw_test" = xyes; then

        # Check for the fftw includes

        if test -z "$detmon_with_fftw_includes"; then
            detmon_fftw_incdirs="/opt/fftw/include /usr/local/include /usr/include"

            test -n "$CPLDIR" && detmon_fftw_incdirs="$CPLDIR/include \
                $detmon_fftw_incdirs"

            test -n "$FFTWDIR" && detmon_fftw_incdirs="$FFTWDIR/include \
                $detmon_fftw_incdirs"
        else
            detmon_fftw_incdirs="$detmon_with_fftw_includes"
        fi

        ESO_FIND_FILE($detmon_fftw_check_header, $detmon_fftw_incdirs,
                      detmon_fftw_includes)


        # Check for the fftw library

        if test -z "$detmon_with_fftw_libs"; then
            detmon_fftw_libdirs="/opt/fftw/lib /usr/local/lib /usr/lib"

            test -n "$CPLDIR" && detmon_fftw_libdirs="$CPLDIR/lib \
                $detmon_fftw_libdirs"

            test -n "$FFTWDIR" && detmon_fftw_libdirs="$FFTWDIR/lib \
                $detmon_fftw_libdirs"
        else
            detmon_fftw_libdirs="$detmon_with_fftw_libs"
        fi

        ESO_FIND_FILE($detmon_fftw_check_lib, $detmon_fftw_libdirs,
                      detmon_fftw_libraries)


        if test x"$detmon_fftw_includes" = xno || \
            test x"$detmon_fftw_libraries" = xno; then
            detmon_fftw_notfound=""

            if test x"$detmon_fftw_includes" = xno; then
                if test x"$detmon_fftw_libraries" = xno; then
                    detmon_fftw_notfound="(headers and libraries)"
                else
                    detmon_fftw_notfound="(headers)"
                fi
            else
                detmon_fftw_notfound="(libraries)"
            fi

            AC_MSG_ERROR([fftw $detmon_fftw_notfound was not found on your system. Please check!])
        else
            AC_MSG_RESULT([libraries $detmon_fftw_libraries, headers $detmon_fftw_includes])
        fi

        # Set up the symbols

        FFTW_INCLUDES="-I$detmon_fftw_includes"
        FFTW_LDFLAGS="-L$detmon_fftw_libraries"
        LDFLAGS="$LDFLAGS $FFTW_LDFLAGS"
        AC_CHECK_LIB([sfftw], [main], [LIBFFTWC="-lsfftw"], AC_MSG_ERROR([Library fftwcblas not found]))
	AC_DEFINE_UNQUOTED(HAVE_SFFTW, 1, [Define to 1 if you have FFTW v. 2.1.5])
        LIBS="$LIBS $LIBFFTWC"
        LIBFFTW="$LIBFFTWC"
    else
        AC_MSG_RESULT([disabled])
        AC_MSG_WARN([fftw checks have been disabled! This package may not build!])
        FFTW_INCLUDES=""
        FFTW_LDFLAGS=""
        LIBFFTW=""
    fi

    # To be removed after CPL switched to fftw
    FFTW_INCLUDES="$FFTW_INCLUDES"
    FFTW_LDFLAGS="$FFTW_LDFLAGS"
    LIBFFTW="$LIBFFTW"

    AC_SUBST(FFTW_INCLUDES)
    AC_SUBST(FFTW_LDFLAGS)
    AC_SUBST(LIBFFTW)

])



# DETMON_SET_PREFIX(PREFIX)
#---------------------------
AC_DEFUN([DETMON_SET_PREFIX],
[
    unset CDPATH
    # make $PIPE_HOME the default for the installation
    AC_PREFIX_DEFAULT($1)

    if test "x$prefix" = "xNONE"; then
        prefix=$ac_default_prefix
        ac_configure_args="$ac_configure_args --prefix $prefix"
    fi

    if test "x$exec_prefix" = "xNONE"; then
        exec_prefix=$prefix
    fi

])


# DETMON_SET_VERSION_INFO(VERSION, [CURRENT], [REVISION], [AGE])
#----------------------------------------------------------------
# Setup various version information, especially the libtool versioning
AC_DEFUN([DETMON_SET_VERSION_INFO],
[
    detmon_version=`echo "$1" | sed -e 's/[[a-z,A-Z]].*$//'`

    detmon_major_version=`echo "$detmon_version" | \
        sed 's/\([[0-9]]*\).\(.*\)/\1/'`
    detmon_minor_version=`echo "$detmon_version" | \
        sed 's/\([[0-9]]*\).\([[0-9]]*\)\(.*\)/\2/'`
    detmon_micro_version=`echo "$detmon_version" | \
        sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\3/'`

    if test -z "$detmon_major_version"; then detmon_major_version=0
    fi

    if test -z "$detmon_minor_version"; then detmon_minor_version=0
    fi

    if test -z "$detmon_micro_version"; then detmon_micro_version=0
    fi

    DETMON_VERSION="$detmon_version"
    DETMON_MAJOR_VERSION=$detmon_major_version
    DETMON_MINOR_VERSION=$detmon_minor_version
    DETMON_MICRO_VERSION=$detmon_micro_version

    if test -z "$4"; then DETMON_INTERFACE_AGE=0
    else DETMON_INTERFACE_AGE="$4"
    fi

    DETMON_BINARY_AGE=`expr 100 '*' $DETMON_MINOR_VERSION + $DETMON_MICRO_VERSION`
    DETMON_BINARY_VERSION=`expr 10000 '*' $DETMON_MAJOR_VERSION + \
                          $DETMON_BINARY_AGE`

    AC_SUBST(DETMON_VERSION)
    AC_SUBST(DETMON_MAJOR_VERSION)
    AC_SUBST(DETMON_MINOR_VERSION)
    AC_SUBST(DETMON_MICRO_VERSION)
    AC_SUBST(DETMON_INTERFACE_AGE)
    AC_SUBST(DETMON_BINARY_VERSION)
    AC_SUBST(DETMON_BINARY_AGE)

    AC_DEFINE_UNQUOTED(DETMON_MAJOR_VERSION, $DETMON_MAJOR_VERSION,
                       [DETMON major version number])
    AC_DEFINE_UNQUOTED(DETMON_MINOR_VERSION, $DETMON_MINOR_VERSION,
                       [DETMON minor version number])
    AC_DEFINE_UNQUOTED(DETMON_MICRO_VERSION, $DETMON_MICRO_VERSION,
                       [DETMON micro version number])
    AC_DEFINE_UNQUOTED(DETMON_INTERFACE_AGE, $DETMON_INTERFACE_AGE,
                       [DETMON interface age])
    AC_DEFINE_UNQUOTED(DETMON_BINARY_VERSION, $DETMON_BINARY_VERSION,
                       [DETMON binary version number])
    AC_DEFINE_UNQUOTED(DETMON_BINARY_AGE, $DETMON_BINARY_AGE,
                       [DETMON binary age])

    ESO_SET_LIBRARY_VERSION([$2], [$3], [$4])
])


# DETMON_SET_PATHS
#------------------
# Define auxiliary directories of the installed directory tree.
AC_DEFUN([DETMON_SET_PATHS],
[

    if test -z "$plugindir"; then
        plugindir='${libdir}/esopipes-plugins/${PACKAGE}-${VERSION}'
    fi

    if test -z "$privatelibdir"; then
        privatelibdir='${libdir}/${PACKAGE}-${VERSION}'
    fi
    if test -z "$pipedocsdir"; then
        pipedocsdir='${datadir}/doc/esopipes/${PACKAGE}-${VERSION}'
    fi
    htmldir='${pipedocsdir}/html'
            
    if test -z "$configdir"; then
       configdir='${datadir}/${PACKAGE}/config'
    fi

    AC_SUBST(plugindir)
    AC_SUBST(privatelibdir)
    AC_SUBST(htmldir)
    AC_SUBST(pipedocsdir)    
    AC_SUBST(configdir)


    # Define a preprocesor symbol for the plugin search paths

    AC_DEFINE_UNQUOTED(DETMON_PLUGIN_DIR, "esopipes-plugins",
                       [Plugin directory tree prefix])

    eval plugin_dir="$plugindir"
    plugin_path=`eval echo $plugin_dir | \
                sed -e "s/\/${PACKAGE}-${VERSION}.*$//"`

    AC_DEFINE_UNQUOTED(DETMON_PLUGIN_PATH, "$plugin_path",
                       [Absolute path to the plugin directory tree])

])


# DETMON_CREATE_SYMBOLS
#-----------------------
# Define include and library related makefile symbols
AC_DEFUN([DETMON_CREATE_SYMBOLS],
[

    # Symbols for package include file and library search paths

    DETMON_INCLUDES='-I$(top_srcdir)/detmon -I$(top_srcdir)/irplib' 
    DETMON_LDFLAGS='-L$(top_srcdir)/detmon'

    all_includes='$(DETMON_INCLUDES) $(CPL_INCLUDES) $(EXTRA_INCLUDES)'
    all_ldflags='$(DETMON_LDFLAGS) $(CPL_LDFLAGS) $(EXTRA_LDFLAGS)'

    # Library aliases

    LIBDETMON='$(top_builddir)/detmon/libdetmon.la'
    LIBIRPLIB='$(top_builddir)/irplib/libirplib.la'

    # Substitute the defined symbols

    AC_SUBST(DETMON_INCLUDES)
    AC_SUBST(DETMON_LDFLAGS)

    AC_SUBST(LIBDETMON)
    AC_SUBST(LIBIRPLIB)

    # Check for CPL and user defined libraries
    AC_REQUIRE([CPL_CHECK_LIBS])
    AC_REQUIRE([ESO_CHECK_EXTRA_LIBS])

    all_includes='$(DETMON_INCLUDES) $(IRPLIB_INCLUDES) $(CPL_INCLUDES) $(EXTRA_INCLUDES)'
    all_ldflags='$(DETMON_LDFLAGS) $(IRPLIB_LDFLAGS) $(CPL_LDFLAGS) $(EXTRA_LDFLAGS)'

    AC_SUBST(all_includes)
    AC_SUBST(all_ldflags)
])
